# Step 7: Track and Report
### On this page
  * [Set Up a Key Performance Indicator (KPI) Dashboard](https://help.sap.com/docs/leanix/ea/application-modernization-track-report#set-up-a-key-performance-indicator-\(kpi\)-dashboard)
  * [Create a Custom Modernization Dashboard](https://help.sap.com/docs/leanix/ea/application-modernization-track-report#create-a-custom-modernization-dashboard)
  * [Track KPIs in the Architecture Executive Dashboard](https://help.sap.com/docs/leanix/ea/application-modernization-track-report#track-kpis-in-the-architecture-executive-dashboard)
  * [Scaling Your Modernization](https://help.sap.com/docs/leanix/ea/application-modernization-track-report#scaling-your-modernization)


Use dashboards to track progress and keep your stakeholders up to date.
Once you’ve planned your modernization initiative, you can use custom dashboards to craft a clear project narrative and report on key milestones. For a high-level, KPI-driven overview, use the architecture executive dashboard to spot trends and quickly identify when adjustments are needed.
To learn more about setting up dashboards, refer to [Dashboards](https://help.sap.com/docs/leanix/ea/dashboards?locale=en-US&state=PRODUCTION&version=CLOUD "Dashboards enable you to consolidate and interpret data in one place, facilitating informed decision-making and promoting efficient task management. Learn how to create, customize, and manage dashboards.")
